pub struct Client(/* private fields */);Implementations
Sourceimpl Client
impl Client
Sourcepub fn get(
&self,
subscription_id: impl Into<String>,
application_id: impl Into<String>,
) -> RequestBuilder
pub fn get( &self, subscription_id: impl Into<String>, application_id: impl Into<String>, ) -> RequestBuilder
Get a specific application for the requested scope by applicationId
Arguments:
subscription_id: Azure subscription IDapplication_id: The security Application key - unique key for the standard application
Sourcepub fn create_or_update(
&self,
subscription_id: impl Into<String>,
application_id: impl Into<String>,
application: impl Into<Application>,
) -> RequestBuilder
pub fn create_or_update( &self, subscription_id: impl Into<String>, application_id: impl Into<String>, application: impl Into<Application>, ) -> RequestBuilder
Creates or update a security application on the given subscription.
Arguments:
subscription_id: Azure subscription IDapplication_id: The security Application key - unique key for the standard applicationapplication: Application over a subscription scope