pub struct AutomationRuleSet {
pub rules: Vec<AutomationTriggeringRule>,
}Expand description
A rule set which evaluates all its rules upon an event interception. Only when all the included rules in the rule set will be evaluated as ‘true’, will the event trigger the defined actions.
Fields
rules: Vec<AutomationTriggeringRule>Implementations