pub struct DefenderForContainersAwsOffering {Show 13 fields
pub cloud_offering: CloudOffering,
pub kubernetes_service: Option<KubernetesService>,
pub kubernetes_scuba_reader: Option<KubernetesScubaReader>,
pub cloud_watch_to_kinesis: Option<CloudWatchToKinesis>,
pub kinesis_to_s3: Option<KinesisToS3>,
pub container_vulnerability_assessment: Option<ContainerVulnerabilityAssessment>,
pub container_vulnerability_assessment_task: Option<ContainerVulnerabilityAssessmentTask>,
pub enable_container_vulnerability_assessment: Option<bool>,
pub auto_provisioning: Option<bool>,
pub kube_audit_retention_time: Option<i64>,
pub scuba_external_id: Option<String>,
pub mdc_containers_image_assessment: Option<MdcContainersImageAssessment>,
pub mdc_containers_agentless_discovery_k8s: Option<MdcContainersAgentlessDiscoveryK8s>,
}Expand description
The Defender for Containers AWS offering
Fields
cloud_offering: CloudOfferingkubernetes_service: Option<KubernetesService>The kubernetes service connection configuration
kubernetes_scuba_reader: Option<KubernetesScubaReader>The kubernetes to scuba connection configuration
cloud_watch_to_kinesis: Option<CloudWatchToKinesis>The cloudwatch to kinesis connection configuration
kinesis_to_s3: Option<KinesisToS3>The kinesis to s3 connection configuration
container_vulnerability_assessment: Option<ContainerVulnerabilityAssessment>The container vulnerability assessment configuration
container_vulnerability_assessment_task: Option<ContainerVulnerabilityAssessmentTask>The container vulnerability assessment task configuration
enable_container_vulnerability_assessment: Option<bool>Enable container vulnerability assessment feature
auto_provisioning: Option<bool>Is audit logs pipeline auto provisioning enabled
kube_audit_retention_time: Option<i64>The retention time in days of kube audit logs set on the CloudWatch log group
scuba_external_id: Option<String>The externalId used by the data reader to prevent the confused deputy attack
mdc_containers_image_assessment: Option<MdcContainersImageAssessment>The Microsoft Defender container image assessment configuration
mdc_containers_agentless_discovery_k8s: Option<MdcContainersAgentlessDiscoveryK8s>The Microsoft Defender container agentless discovery K8s configuration
Implementations
Sourceimpl DefenderForContainersAwsOffering
impl DefenderForContainersAwsOffering
pub fn new(cloud_offering: CloudOffering) -> Self